@@ -196,8 +196,8 @@ class Scraper:
             return eval('element ' + condition)
         '''
 
-    def enter_text(self, path, text, element=None, clear=False):
-        return self.on_enter_text(path=path, text=text, element=element, clear=clear)
+    def enter_text(self, path: str, text: str, element: any=None, clear: bool=False, timeout: int=0):
+        return self.on_enter_text(path=path, text=text, element=element, clear=clear, timeout=timeout)
 
     def click(self, path, element=None, timeout=0):
         return self.on_click(path=path, element=element, timeout=timeout)
