@@ -111,8 +111,8 @@ class Selenium(Scraper):
     def on_get_current_url(self):
         return self.driver.current_url
 
-    def on_enter_text(self, path, text, clear=False, element=None):
-        element = self.on_xPath(path, element)
+    def on_enter_text(self, path: str, text: str, clear: bool=False, element: any=None, timeout: int=0):
+        element = self.on_xPath(path=path, element=element, timeout=timeout)
         if element is not None:
             if type(element) is list:
                 element = element[0]
