@@ -28,6 +28,8 @@ class WebScraper:
         URL = 'URL'
         LIST = 'LIST'
         DATE = 'DATE'
+        JSON = 'JSON'
+        STRING = 'STRING'
 
     class Properties:
         TEXT = 'text()'
