@@ -1,14 +1,13 @@
 from scrapeanything.utils.config import Config
 from scrapeanything.database.repository import Repository
-from scrapeanything.integration.excel import Excel
-from scrapeanything.integration.csv import Csv
-from scrapeanything.scraper.parser import Parser
 from scrapeanything.database.models import Model
 from scrapeanything.utils.constants import *
 
 import requests
 from enum import Enum
 
+from scrapeanything.utils.types import Types
+
 class Methods(Enum):
     POST = 'POST'
     GET = 'GET'
@@ -38,5 +37,19 @@ class Service:
     def save(self, entity: Model) -> None:
         self.repository.save(entity=entity)
 
-    def wget(self, url: str, parameters: dict=None, method: Methods=Methods.GET) -> any:
-        return requests.get(url=url, data=parameters).text
+    def wget(self, url: str, parameters: dict=None, method: Methods=Methods.GET, response_type: str=Types.JSON) -> any:
+        if method == Methods.GET:
+            response = requests.get(url=url, data=parameters)
+        elif method == Methods.POST:
+            response = requests.post(url=url, data=parameters)
+        else:
+            raise Exception(f'{method} method is not supported')
+
+        if response_type == Types.JSON:
+            return response.json()
+        elif response_type == Types.STRING:
+            return response.text
+        else:
+            raise Exception(f'{response_type} response type is not supported')
+
+
